from tkinter import *
from VIS.Objects._WindowGeometry import WindowGeometry

class SubRoot(Toplevel):
    """A wrapper for the Toplevel class with VIS attributes"""
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.WindowGeometry = WindowGeometry(self)


from VIS.Widgets._MenuItem import MenuItem
from VIS.Widgets._VISMenu import Menu
from VIS.Widgets._QuestionWindow import QuestionWindow
from VIS.Widgets._MenuWindow import MenuWindow

__all__ = ["Menu","MenuItem","MenuWindow","QuestionWindow"]